Module git_hashtable::hash
source · Expand description
Structs
A Hasher for usage with HashMap keys that are already robust hashes (like an
ObjectId).
The first 8 bytes of the hash are used as the HashMap hashA Hasher for usage with HashMap keys that are already robust hashes (like an
ObjectId).
The first 8 bytes of the hash are used as the HashMap hash